@@ -17,7 +17,7 @@ use Text::Abbrev();
 use Exporter ();
 our @ISA = qw{ Exporter };
 
-our $VERSION = '0.005_01';
+our $VERSION = '0.006_01';
 
 our @EXPORT_OK = qw{
     __am_or_pm
@@ -557,8 +557,8 @@ sub _fmt_on_date {
 
     $on_date[1][8]   = "The Company of the Ring reaches Hollin, 1419.\n";
     $on_date[1][13]  = "The Company of the Ring reaches the West-gate of Moria at nightfall, 1419.\n";
-    $on_date[1][14]  = "The Company of the Ring spends the night in Moria hall 21, 1419.\n";
-    $on_date[1][15]  = "The Bridge of Khazad-dum, and the fall of Gandalf, 1419.\n";
+    $on_date[1][14]  = "The Company of the Ring spends the night in Moria Hall 21, 1419.\n";
+    $on_date[1][15]  = "The Bridge of Khazad-dum, and fall of Gandalf, 1419.\n";
     $on_date[1][17]  = "The Company of the Ring comes to Caras Galadhon at evening, 1419.\n";
     $on_date[1][23]  = "Gandalf pursues the Balrog to the peak of Zirakzigil, 1419.\n";
     $on_date[1][25]  = "Gandalf casts down the Balrog, and passes away.\n" .
@@ -1369,7 +1369,7 @@ and month, and the weekday name is omitted if the holiday is part of no
 week. So (assuming times for all events):
 
  Sun 25 Ret 1419  3:00:00 PM # Ring destroyed
- Myd 1419 12:00:OO PM        # Wedding of Aragorn and Arwen
+ Myd 1419 12:00:00 PM        # Wedding of Aragorn and Arwen
 
 =item %D
 
@@ -1804,7 +1804,7 @@ L<http://howardhinnant.github.io/date_algorithms.html#civil_from_days>.
 
 This subroutine assumes no particular calendar, though it does assume
 the Gregorian year-length rules, which have also been adopted for the
-Shire calendar. If you feed it am honest-to-God Rata Die day (i.e. days
+Shire calendar. If you feed it an honest-to-God Rata Die day (i.e. days
 since December 31 of proleptic Gregorian year 0) you get back the
 Gregorian year and the day of that year (C<1-366>). If you feed it a
 so-called Shire Rata Die (i.e. days since 1 Yule of Shire year 0) you
@@ -1991,7 +1991,8 @@ L<DateTime::Fiction::JRRTolkien::Shire|DateTime::Fiction::JRRTolkien::Shire>
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<http://rt.cpan.org>, or in electronic mail to the author.
+L<https://github.com/trwyant/perl-Date-Tolkien-Shire-Data/issues>, or in
+electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -1999,7 +2000,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2017-2019 by Thomas R. Wyant, III
+Copyright (C) 2017-2021 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
